==> hinemos_src-2.4.2.tar.gz: Hinemos_src-2.4.2/PerformanceManagement/src/com/clustercontrol/performanceMGR/dao/CalculatedDataDAO.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performanceMGR.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.sql.Types;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.ejb.EJBException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.commons.util.ConnectionManager;
import com.clustercontrol.performanceMGR.bean.CollectedDataInfo;

/**
 * 収集した性能値をDBに保存、読み出しするDAOクラス
 * 
 * 
 * @version 2.0.0
 * @since 1.0
 */
public class CalculatedDataDAO {
	
//	ログ出力
	protected static Log m_log = LogFactory.getLog(CalculatedDataDAO.class);
	
	/**
	 * コンストラクター
	 */
	public CalculatedDataDAO(){
	}
	
	/**
	 * 収集された性能値を収集ID、SNMPのOID、ファシリティID、期間（開始の時刻、終了の時刻）で検索します。
	 *
	 * 
	 * @param collectorID 収集ID
	 * @param itemCode　収集項目コード
	 * @param deviceIndex  デバイス番号
	 * @param deviceName  デバイス名
	 * @param facilityID ファシリティID
	 * @param startDate (検索の）開始時刻
	 * @param stopDate　（検索の）終了時刻
	 * @return　収集された性能値のコレクション
	 * @throws EJBException
	 */
	public List select(
			String collectorID, 
			String itemCode, 
			int deviceIndex,
			String deviceName,
			String facilityID,
			Date startDate,
			Date stopDate )
	throws EJBException{
		
		m_log.debug("select() start :" + collectorID + " " + itemCode + " " + deviceIndex + " " + facilityID);
		ArrayList<CollectedDataInfo> ret = new ArrayList<CollectedDataInfo>();  // DBから取得したデータを格納するリスト
		
		Connection conn = null;
		PreparedStatement stmt =null;
		ResultSet res = null; 
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			//		SQL文の作成
			String sql = "SELECT * FROM CALCULATED_DATA WHERE " + 
			"COLLECTORID=? AND " + 
			"ITEM_CODE=? AND " + 
			"DEVICE_INDEX=? AND " + 
			"FACILITYID=? AND " + 
			"DATE_TIME BETWEEN ? AND ?" +
			"ORDER BY DATE_TIME";
			
			// SQL文発行準備
			stmt = conn.prepareStatement(sql);
			
			Timestamp start = new Timestamp(startDate.getTime());
			Timestamp stop  = new Timestamp(stopDate.getTime());
			
			stmt.setString(1,collectorID);
			stmt.setString(2, itemCode);
			stmt.setInt(3, deviceIndex);
			stmt.setString(4, facilityID);
			stmt.setTimestamp(5, start);
			stmt.setTimestamp(6, stop);
			
			res = stmt.executeQuery();
			
			while(res.next()) {
				CollectedDataInfo data = new CollectedDataInfo(facilityID, itemCode, deviceIndex, deviceName);
				data.setDate(new Date(res.getTimestamp("DATE_TIME").getTime()));
				
				if(res.getObject("VALUE") != null){	
					data.setValue(res.getDouble("VALUE"));
				} else {
					data.setValue(Double.NaN);  // DBにnullが入っている場合は性能値が算出不能だった場合
				}
				ret.add(data);
			}
		} catch (SQLException e) {
			m_log.error("select() error :" + facilityID + " EJBException ",e);
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(res != null){
					res.close();
				}
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("select() error :" + facilityID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
		}	
		m_log.debug("select() end   :" + collectorID + " " + itemCode + " " + deviceIndex + " " + facilityID);
		
		return ret;
	}
	
	/**
	 * 収集した性能値を収集IDで削除します。
	 * 
	 * 収集設定に紐付けられた性能値を一括で削除します。
	 * 
	 * @param collectorID　収集ID
	 * @throws SQLException
	 */
	public void delete(String collectorID)
	throws EJBException{
		
		m_log.debug("delete() start :" + collectorID );

		Connection conn = null;
		PreparedStatement stmt = null;
		
		try{
			conn = ConnectionManager.getConnectionManager().getConnection();
			//conn.setAutoCommit(false);
			//SQL文の定義
			String sql = "DELETE FROM CALCULATED_DATA WHERE COLLECTORID = ? ";
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1,collectorID );
			
			stmt.executeUpdate();
		} catch (SQLException e) {
			m_log.error("delete() error :" + collectorID + " EJBException ");
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("delete() error :" + collectorID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
			m_log.debug("delete() end   :" + collectorID );
		}	
	}
	
	/**
	 * 収集した性能値をインサートします。
	 * 
	 * @param collectorID　収集ID
	 * @param data 計算済み性能値情報
	 * @throws SQLException
	 */
	public void insert(String collectorID, CollectedDataInfo data)
	throws EJBException{
		
		m_log.debug("insert() start : " + collectorID +
				" " + data.getItemCode() +
				" " + data.getDeviceIndex() +
				" " + data.getFacilityID());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		Timestamp time = new Timestamp(data.getDate().getTime());
		
		try{
			conn = ConnectionManager.getConnectionManager().getConnection();
			//SQL文の定義
			String sql = "INSERT INTO CALCULATED_DATA " +
			"(collectorId, " +
			"item_code, " +
			"device_index, " +
			"date_time, " +
			"facilityid, " +
			"value) " +
			"values (?,?,?,?,?,?);";
			
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1,collectorID);
			stmt.setString(2, data.getItemCode());
			stmt.setInt(3, data.getDeviceIndex());
			stmt.setTimestamp(4, time);
			stmt.setString(5, data.getFacilityID());
			if(Double.isNaN(data.getValue())){
				stmt.setNull(6, Types.DOUBLE);  // 性能値が算出不能だった場合はnullを書き込む
			} else {
				stmt.setDouble(6, data.getValue());
			}
			
			int row = stmt.executeUpdate();
			
			if (row != 1) {
				String msg = "result row is not 1";
				throw new SQLException(msg);
			}
		} catch (SQLException e) {
			m_log.error("insert() error :" + collectorID + " EJBException ");
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(stmt != null){
					stmt.close();}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("insert() error :" + collectorID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
			m_log.debug("insert() end   : " + collectorID +
					" " + data.getItemCode() +
					" " + data.getDeviceIndex() +
					" " + data.getFacilityID());
		}	
	}
	/**
	 * 保存期間を過ぎた実績値を削除します。
	 * 
	 * @param collectorID 収集ID
	 * @param startDate 開始時刻
	 * @throws EJBException
	 */
	public void deleteOverPresave(String collectorID , Date startDate)
		throws EJBException{
			
			m_log.debug("deleteOrverPresave() start :" + collectorID + " " + startDate.toString());

			Connection conn = null;
			PreparedStatement stmt = null;
			Timestamp time = new Timestamp(startDate.getTime());
			
			try{
				conn = ConnectionManager.getConnectionManager().getConnection();
				//conn.setAutoCommit(false);
				//SQL文の定義
				String sql = "DELETE FROM CALCULATED_DATA WHERE COLLECTORID = ? AND DATE_TIME < ?";
				//SQL文のセット
				stmt = conn.prepareStatement(sql);
				
				stmt.setString(1,collectorID );
				stmt.setTimestamp(2,time);
				
				stmt.executeUpdate();
			} catch (SQLException e) {
				m_log.debug("deleteOrverPresave() error :" + collectorID + " " + startDate.toString() + "  EJBException ");

				throw new EJBException(e.getMessage());
			}  finally{
				
				//コネクション、結果セット、プリペアドステートメントのクロース
				try {
					if(stmt != null){
						stmt.close();
					}
					if(conn != null){
						conn.close();
					}
				} catch (SQLException e1) {
					m_log.debug("deleteOrverPresave() error :" + collectorID + " " + startDate.toString() + "  EJBException ");
					throw new EJBException(e1.getMessage());
				}
				m_log.debug("deleteOrverPresave() end :" + collectorID + " " + startDate.toString() + "  EJBException ");
			}	
	}

/**
 * 収集回数を再カウントします。
 * 
 * @param collectorID
 * @return
 * @throws EJBException
 */
	public int recountFromDB(String collectorID)throws EJBException{
		
		m_log.debug("recountFromDB() start :" + collectorID );
		
		Connection conn = null;
		PreparedStatement stmt =null;
		ResultSet res = null; 
		int ret = 0;
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			//		SQL文の作成
			String sql = "SELECT COUNT(*) AS COLLECT_COUNT FROM calculated_data " +
			"WHERE collectorid =? group by item_code , facilityid limit 1";
			
			// SQL文発行準備
			stmt = conn.prepareStatement(sql);
			
			
			stmt.setString(1,collectorID);
			
			res = stmt.executeQuery();
			
			if(res.next()){
				ret = res.getInt("COLLECT_COUNT");
			}
		} catch (SQLException e) {
			m_log.error("recountFromDB() error :" + collectorID + " EJBException ",e);
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(res != null){
					res.close();
				}
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("recountFromDB() error :" + collectorID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
		}	
		m_log.debug("recountFromDB() end   :" + collectorID + " ");
		
		return ret;
	}
}

==> hinemos_src-2.4.3.tar.gz: Hinemos_src-2.4.3/PerformanceManagement/src/com/clustercontrol/performanceMGR/dao/CalculatedDataDAO.java <==
/*
 
 Copyright (C) 2006 NTT DATA Corporation
 
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 */

package com.clustercontrol.performanceMGR.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Timestamp;
import java.sql.Types;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import javax.ejb.EJBException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.commons.util.ConnectionManager;
import com.clustercontrol.performanceMGR.bean.CollectedDataInfo;

/**
 * 収集した性能値をDBに保存、読み出しするDAOクラス
 * 
 * 
 * @version 2.0.0
 * @since 1.0
 */
public class CalculatedDataDAO {
	
//	ログ出力
	protected static Log m_log = LogFactory.getLog(CalculatedDataDAO.class);
	
	/**
	 * コンストラクター
	 */
	public CalculatedDataDAO(){
	}
	
	/**
	 * 収集された性能値を収集ID、SNMPのOID、ファシリティID、期間（開始の時刻、終了の時刻）で検索します。
	 *
	 * 
	 * @param collectorID 収集ID
	 * @param itemCode　収集項目コード
	 * @param deviceIndex  デバイス番号
	 * @param deviceName  デバイス名
	 * @param facilityID ファシリティID
	 * @param startDate (検索の）開始時刻
	 * @param stopDate　（検索の）終了時刻
	 * @return　収集された性能値のコレクション
	 * @throws EJBException
	 */
	public List select(
			String collectorID, 
			String itemCode, 
			int deviceIndex,
			String deviceName,
			String facilityID,
			Date startDate,
			Date stopDate )
	throws EJBException{
		
		m_log.debug("select() start :" + collectorID + " " + itemCode + " " + deviceIndex + " " + facilityID);
		ArrayList<CollectedDataInfo> ret = new ArrayList<CollectedDataInfo>();  // DBから取得したデータを格納するリスト
		
		Connection conn = null;
		PreparedStatement stmt =null;
		ResultSet res = null; 
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			//		SQL文の作成
			String sql = "SELECT * FROM CALCULATED_DATA WHERE " + 
			"COLLECTORID=? AND " + 
			"ITEM_CODE=? AND " + 
			"DEVICE_INDEX=? AND " + 
			"FACILITYID=? AND " + 
			"DATE_TIME BETWEEN ? AND ?" +
			"ORDER BY DATE_TIME";
			
			// SQL文発行準備
			stmt = conn.prepareStatement(sql);
			
			Timestamp start = new Timestamp(startDate.getTime());
			Timestamp stop  = new Timestamp(stopDate.getTime());
			
			stmt.setString(1,collectorID);
			stmt.setString(2, itemCode);
			stmt.setInt(3, deviceIndex);
			stmt.setString(4, facilityID);
			stmt.setTimestamp(5, start);
			stmt.setTimestamp(6, stop);
			
			res = stmt.executeQuery();
			
			while(res.next()) {
				CollectedDataInfo data = new CollectedDataInfo(facilityID, itemCode, deviceIndex, deviceName);
				data.setDate(new Date(res.getTimestamp("DATE_TIME").getTime()));
				
				if(res.getObject("VALUE") != null){	
					data.setValue(res.getDouble("VALUE"));
				} else {
					data.setValue(Double.NaN);  // DBにnullが入っている場合は性能値が算出不能だった場合
				}
				ret.add(data);
			}
		} catch (SQLException e) {
			m_log.error("select() error :" + facilityID + " EJBException ",e);
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(res != null){
					res.close();
				}
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("select() error :" + facilityID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
		}	
		m_log.debug("select() end   :" + collectorID + " " + itemCode + " " + deviceIndex + " " + facilityID);
		
		return ret;
	}
	
	/**
	 * 収集した性能値を収集IDで削除します。
	 * 
	 * 収集設定に紐付けられた性能値を一括で削除します。
	 * 
	 * @param collectorID　収集ID
	 * @throws SQLException
	 */
	public void delete(String collectorID)
	throws EJBException{
		
		m_log.debug("delete() start :" + collectorID );

		Connection conn = null;
		PreparedStatement stmt = null;
		
		try{
			conn = ConnectionManager.getConnectionManager().getConnection();
			//conn.setAutoCommit(false);
			//SQL文の定義
			String sql = "DELETE FROM CALCULATED_DATA WHERE COLLECTORID = ? ";
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1,collectorID );
			
			stmt.executeUpdate();
		} catch (SQLException e) {
			m_log.error("delete() error :" + collectorID + " EJBException ");
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("delete() error :" + collectorID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
			m_log.debug("delete() end   :" + collectorID );
		}	
	}
	
	/**
	 * 収集した性能値をインサートします。
	 * 
	 * @param collectorID　収集ID
	 * @param data 計算済み性能値情報
	 * @throws SQLException
	 */
	public void insert(String collectorID, CollectedDataInfo data)
	throws EJBException{
		
		m_log.debug("insert() start : " + collectorID +
				" " + data.getItemCode() +
				" " + data.getDeviceIndex() +
				" " + data.getFacilityID());
		
		Connection conn = null;
		PreparedStatement stmt = null;
		Timestamp time = new Timestamp(data.getDate().getTime());
		
		try{
			conn = ConnectionManager.getConnectionManager().getConnection();
			//SQL文の定義
			String sql = "INSERT INTO CALCULATED_DATA " +
			"(collectorId, " +
			"item_code, " +
			"device_index, " +
			"date_time, " +
			"facilityid, " +
			"value) " +
			"values (?,?,?,?,?,?);";
			
			//SQL文のセット
			stmt = conn.prepareStatement(sql);
			
			stmt.setString(1,collectorID);
			stmt.setString(2, data.getItemCode());
			stmt.setInt(3, data.getDeviceIndex());
			stmt.setTimestamp(4, time);
			stmt.setString(5, data.getFacilityID());
			if(Double.isNaN(data.getValue())){
				stmt.setNull(6, Types.DOUBLE);  // 性能値が算出不能だった場合はnullを書き込む
			} else {
				stmt.setDouble(6, data.getValue());
			}
			
			int row = stmt.executeUpdate();
			
			if (row != 1) {
				String msg = "result row is not 1";
				throw new SQLException(msg);
			}
		} catch (SQLException e) {
			m_log.error("insert() error :" + collectorID + " EJBException ");
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(stmt != null){
					stmt.close();}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("insert() error :" + collectorID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
			m_log.debug("insert() end   : " + collectorID +
					" " + data.getItemCode() +
					" " + data.getDeviceIndex() +
					" " + data.getFacilityID());
		}	
	}
	/**
	 * 保存期間を過ぎた実績値を削除します。
	 * 
	 * @param collectorID 収集ID
	 * @param startDate 開始時刻
	 * @throws EJBException
	 */
	public void deleteOverPresave(String collectorID , Date startDate)
		throws EJBException{
			
			m_log.debug("deleteOrverPresave() start :" + collectorID + " " + startDate.toString());

			Connection conn = null;
			PreparedStatement stmt = null;
			Timestamp time = new Timestamp(startDate.getTime());
			
			try{
				conn = ConnectionManager.getConnectionManager().getConnection();
				//conn.setAutoCommit(false);
				//SQL文の定義
				String sql = "DELETE FROM CALCULATED_DATA WHERE COLLECTORID = ? AND DATE_TIME < ?";
				//SQL文のセット
				stmt = conn.prepareStatement(sql);
				
				stmt.setString(1,collectorID );
				stmt.setTimestamp(2,time);
				
				stmt.executeUpdate();
			} catch (SQLException e) {
				m_log.debug("deleteOrverPresave() error :" + collectorID + " " + startDate.toString() + "  EJBException ");

				throw new EJBException(e.getMessage());
			}  finally{
				
				//コネクション、結果セット、プリペアドステートメントのクロース
				try {
					if(stmt != null){
						stmt.close();
					}
					if(conn != null){
						conn.close();
					}
				} catch (SQLException e1) {
					m_log.debug("deleteOrverPresave() error :" + collectorID + " " + startDate.toString() + "  EJBException ");
					throw new EJBException(e1.getMessage());
				}
				m_log.debug("deleteOrverPresave() end :" + collectorID + " " + startDate.toString() + "  EJBException ");
			}	
	}

	/**
	 * 収集回数を再カウントします。
	 * 
	 * @param collectorID
	 * @return 再カウントした結果の収集件数（失敗した場合は負数が返る）
	 * @throws EJBException
	 */
	public int recountFromDB(String collectorID)throws EJBException{
		
		m_log.debug("recountFromDB() start :" + collectorID );
		
		Connection conn = null;
		PreparedStatement stmt =null;
		ResultSet res = null; 
		int ret = -1;
		try {
			conn = ConnectionManager.getConnectionManager().getConnection();
			
			// 指定された収集IDの任意の1件を取り出し、そのitem_codeとfacilityidを取得する。
			final String preQuery = "SELECT item_code, facilityid FROM calculated_data" + 
									" where collectorid = ? LIMIT 1";
			stmt = conn.prepareStatement(preQuery);
			stmt.setString(1, collectorID);
			res = stmt.executeQuery();
			if (!res.next()) {
				// 1件もとれない（処理に失敗した）場合は負数を返す
				return -1;
			}
			final String item_code = res.getString(1);
			final String facilityid = res.getString(2);
			
			// 指定された収集IDで何回収集が行われたかを取得する。
			// 収集の開始から現時点に至るまでに、item_code/facilityidが変わることは
			// ありえないことと、同一時間帯にitem_code（収集対象の情報種類）とfacilityid
			// （収集対象ノード）の数だけ重複して情報を収集することから、ある特定のitem_code
			// とfacilityidに絞ってその件数を数えれば、収集を実施した回数がわかることになる。
			final String cntQuery = "SELECT COUNT(*) FROM calculated_data " +
				"WHERE collectorid = ? AND item_code = ? AND facilityid = ?";
			stmt = conn.prepareStatement(cntQuery);
			stmt.setString(1, collectorID);
			stmt.setString(2, item_code);
			stmt.setString(3, facilityid);
			res = stmt.executeQuery();
			if (!res.next()) {
				// 1件もとれない（処理に失敗した）場合は負数を返す
				return -1;
			}
			ret = res.getInt(1);
			
		} catch (SQLException e) {
			m_log.error("recountFromDB() error :" + collectorID + " EJBException ",e);
			throw new EJBException(e.getMessage());
		}  finally{
			
			//コネクション、結果セット、プリペアドステートメントのクロース
			try {
				if(res != null){
					res.close();
				}
				if(stmt != null){
					stmt.close();
				}
				if(conn != null){
					conn.close();
				}
			} catch (SQLException e1) {
				m_log.error("recountFromDB() error :" + collectorID + " EJBException ");
				throw new EJBException(e1.getMessage());
			}
			m_log.debug("recountFromDB() end   :" + collectorID + " ");
		}
		
		return ret;
	}
}
